Simulate a pedigree for advanced intercross lines (a table of individual, mom, dad, sex) so that the last generation reaches a desired sample size n
sim_ail_pedigree_fix_n(
ngen = 12,
nkids_per = 5,
nsample_ngen = 150,
npairs = NULL,
method = c("last2", "sub2"),
design = c("nosib", "random")
)A data frame with five columns: individual ID, mother ID,
father ID, sex, and generation. Founders have 0 for mother
and father ID. Sex is coded 0 for female and 1 for male.
Number of generations of outbreeding
Number of offspring per pair for the last generation
Number of individuals desired at the last generation
Number of breeding pairs at each generation. If
missing, we use 30 when method="last2" and 300 when
method="sub2".
Method used to generate pedigree: either expand at the last two generations or generate a pedigree with a large number of pairs and select a subset to have the desired sample size.
How to choose crosses: either random but avoiding siblings, or completely at random
The default value for npairs depends on the choice of method.
For method="last2", we use a default of npairs=30; for
method="sub2", we use a default of npairs=300.
sim_from_pedigree(),
sim_ril_pedigree(), sim_ail_pedigree(),
sim_do_pedigree(), sim_4way_pedigree(),
sim_do_pedigree_fix_n()
tab <- sim_ail_pedigree_fix_n(12)
Run the code above in your browser using DataLab