Simulate a pedigree for Diversity Outbred (DO) mice (a table of individual, mom, dad, sex) so that the last generation reaches a desired sample size.
sim_do_pedigree_fix_n(
ngen = 12,
nkids_per = 5,
nccgen = 15,
nsample_ngen = 150,
npairs = NULL,
method = c("last2", "sub2", "fixcc"),
design = c("nosib", "random"),
selc.method = c("byfamily", "byindiv")
)A data frame with six columns: individual ID, mother ID, father
ID, sex, generation, and TRUE/FALSE indicator for whether DO or pre-DO.
Founders have 0 for mother and father ID. Sex is coded 0 for
female and 1 for male.
Number of generations of outbreeding
Number of offspring per pair for the last generation
The number of generations for each CC line, only used
when method is not "fixcc".
Number of individuals desired at the last generation
Number of breeding pairs at each generation. If
missing, we use 30 when method="last2" and 300 when
method="sub2".
Method used to generate the pedigree: either expand
at the last two generations or generate a pedigree with a large
number of pairs and then select a subset to have the desired sample
size. With method="fixcc", we use the pre-CC generations as performed at the
Jackson Lab.
How to choose crosses: either random but avoiding siblings, or completely at random
Method used to select the individuals from last generation.
The default number of breeding pairs depends on the chosen
method. With method="last2", the default is npairs=30;
with method="sub2", the default is npairs=300;
with method="fixcc", npairs is ignored and is fixed at 144.
sim_from_pedigree(),
sim_ril_pedigree(), sim_ail_pedigree(),
sim_do_pedigree(), sim_4way_pedigree(),
sim_ail_pedigree_fix_n()
tab <- sim_do_pedigree_fix_n(8)
Run the code above in your browser using DataLab