Output a random meiotic product from an input individual.
sim_meiosis(parent, m = 10, p = 0, obligate_chiasma = FALSE, Lstar = NULL)A list with alleles in chromosome intervals (as integers) and locations of the right endpoints of those intervals.
An individual object, as output by
create_parent() or cross()
interference parameter for chi-square model
Proportion of chiasmata coming from no-interference process.
If TRUE, require an obligate chiasma on the 4-strand bundle at meiosis.
Adjusted chromosome length, if
obligate_chiasma=TRUE. Calculated if not provided.
Simulations are under the Stahl model with the interference parameter being an integer. This is an extension of the chi-square model, but with chiasmata being the superposition of two processes, one following the chi-square model and the other exhibiting no interference.
Copenhaver, G. P., Housworth, E. A. and Stahl, F. W. (2002) Crossover interference in arabidopsis. Genetics 160, 1631--1639.
Foss, E., Lande, R., Stahl, F. W. and Steinberg, C. M. (1993) Chiasma interference as a function of genetic distance. Genetics 133, 681--691.
Zhao, H., Speed, T. P. and McPeek, M. S. (1995) Statistical analysis of crossover interference using the chi-square model. Genetics 139, 1045--1056.
create_parent(), cross(),
sim_crossovers(), calc_Lstar()
ind <- create_parent(100, 1:2)
prod <- sim_meiosis(ind)
Run the code above in your browser using DataLab