Learn R Programming

simcross (version 0.10)

simcross-package: simcross: Simulate Experimental Crosses

Description

logo

Simulate and plot general experimental crosses. The focus is on simulating genotypes with an aim towards flexibility rather than speed. Meiosis is simulated following the Stahl model, in which chiasma locations are the superposition of two processes: a proportion p coming from a process exhibiting no interference, and the remainder coming from a process following the chi-square model.

Arguments

Author

Maintainer: Karl W Broman broman@wisc.edu (ORCID)

Authors:

See Also