CCcolors: Collaborative Cross colors
Description
The original/official palette is the original eight colors for the
Collaborative Cross founder strains. The alt palette is a slightly
modified version, but still not color-blind friendly. The default
(new) palette was derived from the the Okabe-Ito color blind
friendly palette in Wong (2011) Nature Methods
tools:::Rd_expr_doi("10.1038/nmeth.1618").
Usage
CCcolors(palette = c("new", "alt", "original", "official"))Value
vector of eight colors
Arguments
- palette
Which version of the colors to use? (New, alternative, or original/official)
Details
Get the vector of colors for the Collaborative Cross